$TITLE Reduced Form Global SAMs for GLOBE Version 2 GTAP804
$OFFUPPER
*$OFFLISTING OFFSYMXREF OFFSYMLIST
$ONEMPTY

*############## WORK TO DO ON THIS VERSION #############################
$ontext

1.   Estimates of the internal balance for each region are required
     Current version assumes all have values equal to ZERO

2.   Adjustments for income tax payments

3.   Rounding of database to remove small differences in row and column totals

$offtext

*############## GENERAL INFORMATION #############################
$ontext

This programme was developed by Scott McDonald

 Scott McDonald
 Dept of Economics & Strategy
 Oxford Brookes University
 Wheatley Campus, Wheatley
 Oxford, OX33 1HX, UK
 email:
    smcdonald@brookes.ac.uk

This version works with version 804 of GTAP.

This version last updated 10 February 2012

Scott McDonald, "Deriving Reduced Form Global Social Accounting
Matrices from GTAP version 7 and 8 Data", mimeo.

Copyright (c) 2012 Scott McDonald

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

A copy of the GNU GPL, gpl.txt, is included with the programme files.

Do NOT remove this notice if you redistribute this programme

If you use this programme you should acknowledge the source and not claim
authorship. Altered versions should be clearly distinguished from the original.

$offtext
*############## USER GUIDE ######################################
$ontext

SOFTWARE REQUIREMENTS

  1) This programme is known to work with versions of GAMS 250 after and
     including distribution 23.7. It is believed to work with all versions
     of GAMS 250 that include the GDXXRW utilities, i.e, since
     distribution 21.0 in May 2003.

  2) It is also useful to have a copy of GDXVIEWER - this is one of the
     WTOOLS utilities developed by Erwin Kalvelagen. GDXViewer is now
     packaged with GAMS.

DATA REQUIREMENTS

  1) No GTAP data are provided. The user must have a licensed version
     of the GTAP database complete with the GTAPAgg programme.

  2) The computer code and instructions for generating a Global SAM from
     the GTAP database are available from www.cgemod.org.uk and
     the GTAP web site

  2) All the sets and set mapping required to use the GAMS programmes for
     specific versions of the GTAP database are provided from
     a single Excel workbook.

USER INSTRUCTIONS
   (These instructions assume the user is working in a Windows
    environment using GAMSIDE and Microsoft Excel 2003, 2007 or 2010)

  1) The programme files are made available in a WinZip archive - ???.zip.

  2) The programme files are organised so that they can be used as a
     GAMS User Model Library (see the GAMS documentation for information
     on using User Model Libraries). These instruction assume that files
     in ???.zip have been extracted to a directory - ???.

  3) Create a directory for the programme. The path to this directory
     does not need to follow standard/old DOS conventions.

     Create a project file (*.gpr) in this directory.

  4) To copy the programme files to the project directory.
     In GAMSIDE with the project file controlling paths do the following
     a) Locate the User Model Library
          File>Model Library>Open User Model Library and then select the
          file ???.glb in the directory gsamlib
     b) Double click on the NAME of the version of the programme that
        corresponds to the version of the GTAP database with which you are
        working. ALL the files needed to run the programme other than the
        GTAP database file will be copied to the directory containing the
        project file.
        NB: A brief description of the programme is provided in the window
            at the bottom of the User Mode Library window.

  5) Read and study the GAMS programme.

  6) Create the database for the programme

  7) Check that programme compiles (by using SHIFT+F9).
        If the steps above have been followed there should be no problems.
        a) Some users can have problems with the GDXXRW facility
           that generates the file data_in.gdx from the Excel file. These
           problems mostly seem to originate with a corruption of the
           'LAYOUT' worksheet and result in an error message saying the
           file data_in.gdx does not exist. To overcome this type of problem
              i)  check that gdxxrw.exe exists in the GAMS directory
              ii) copy the contents of the worksheet 'LAYOUT2' and replace
                  the worksheet 'LAYOUT' using Paste Special
        b) .

  8) Run the programme. The output to the working directory should be as
     follows:
     a)
     b)
     c)

     NB: For version 6 of the GTAP database the directory will be in the
         order of ???MB.

  9)

  10)

  11)These notes relate to situations where a user wishes to work with
     another version of the GTAP database. It is assumed this will be a later
     version.
     A new workbook - data_gtp_**.xls - will need to be compiled.
     a) Using the file gtp_sets_v60.xls as a template
        i)   Get the 'new' sector, region, factor and margin codes and
             descriptions from the GTAP database and copy them into the
             worksheet 'Set data from GTAPAgg'
        ii)  Check that the worksheets
             'Set creation regions/sectors/factor/margins' have all updated
             correctly - NB the number of entries in each group of
             codes is the critical point.
        iii) Compile the new sets in the worksheet 'Compiling Sets'
     b) Using the file data_gtp_60.xls as a template
        i)   Generate a revise worksheet 'Sets' - using copy and paste
             SPECIAL from the new file gtp_sets_V**.xls.
        ii)  Generate a revise worksheet 'Maps' - using copy and paste
             from the new worksheet 'Sets'.
        iii) The worksheet 'Layout' should NOT need to be changed unless
             new sets or maps are created.
     c) Update the programme file to read the new sets and maps.

     d) Some general suggestions
        i)   Spaces in the cells of the file data_gtp_**.xls are a
             problem - to GAMS spaces are characters.
        ii)  If the orderings in the mapping sets are not consistent the
             mappings implemented will be wrong.
        iii) 'Corruption' of the worksheet 'Layout' will cause the sets
             maps not to be read in.
        iv)  The codes used for account names in the GTAP database may
             have changed.
        v)   'Big' initial 'errors' (say entries in the first DIFFTOT that
             are greater than 1) are likely to be due to an error in the
             sets and maps files.
        vi)  'Small' initial 'errors' (say less that 0.01) are more likely
             to rounding issues due to the degree of precision in the
             GTAP database.
        vii) When adjusting the programme to remove 'errors' due to
             the degree precision in the database, it is best by far to
             work through the accounts as they appear in the SAM, i.e.,
             start with the import commodity accounts, then domestic
             commodities, etc.

$offtext
*############## PROGRAMME DESCRIPTION ##################################
$ontext
This programme reorganises GTAP SAM data into the version of a Global SAM
used by version 2 of the GLOBE model (GLB2).

 The programme
        adjusts for the law of one price
        generates data for the Globe region




$offtext
*############## 1. OUTLINE OF PROGRAMME ################################

$ontext
Programme Navigation

     PROGRAMME DESCRIPTION



$offtext


*############## 2. SET and PARAMETER DECLARATIONS ##########################

*#### SET DECLARATIONS

SETS

 ss              SAM accounts

 ssn(ss)         SAM accounts excluding TOTAL

*   Commodity sets
 mcc(ss)         Imported Commodities
 mccts(mcc)      Imported commodities WITH input subsidies
 mcctsn(mcc)     Imported commodities WITHOUT input subsidies

 dcc(ss)         Domestic Commodities
 dccts(dcc)      Domestic commodities WITH input subsidies
 dcctsn(dcc)     Domestic commodities WITHOUT input subsidies

 cc(ss)          Composite Commodities

 en              energy commodities

*   Activity sets
 aa(ss)          Activities
 a2              Production commodities Activities in GTAP

*   Factor sets
 ff (ss)         Factors

*   Tax sets
 tmmtax(ss)      Import taxes
 teetax(ss)      Export taxes
 smmtax(ss)      Sales Taxes on imported goods and services
 sddtax(ss)      Sales Taxes on domestic goods and services
 sstax(ss)       Sales Taxes on composite goods and services
 fftax(ss)       Taxes on Factors

*   Trade sets
 otppmarg(ss)    Other trade and transport costs
 wtppmarg(ss)    Water trade and transport costs
 atppmarg(ss)    Air trade and transport costs

 vsttmarg(ss)    Exports of trade and transport services

 ww(ss)          Rest of the World

*   investment sets
 ii(ss)          Investment

*   Regions set
 kk              Regions

*   Time Periods set
 tt              time periods 1965 to 2010


*   Mapping sets

 mapsmtax(mcc,smmtax)      Import Sales tax mapping

 mapinsubm(smmtax,mcc)     Input subsidy mapping

 mapstaxsm(sstax,smmtax)   Input subsidy mapping for composite goods

 mapsdtax(dcc,sddtax)      Domestic Sales tax mapping

 mapinsubd(sddtax,dcc)     Domestic input subsidy mapping

 mapstaxsd(sstax,sddtax)   Input subsidy mapping for composite goods

 mapsimpcom(cc,mcc)        Imports to Composite commodity mapping

 mapsdomcom(cc,dcc)        Domestic to Composite commodity mapping

 maptrad(ww,kk)            Trade account mapping

 mapkk_ww(kk,ww)           Trade account mapping

 mapcc_en(cc,en)           Mapping from energy to composite commodities

*  Report sets

 tsmset       sets for summary info on sales taxes on imports commod
 tsdset       sets for summary info on sales taxes on domestic commod

* Set used to control model flow

 cons         set of programme controlling parameters

* Other sets
 nonhh(ss)    Activities government and investment saving demand

      ;

* Setting up ALIASES

 ALIAS(ss,ssp), (ssn,ssnp),
      (mcc,mccp), (dcc,dccp), (cc,ccp),
      (aa,aap), (a2,aa2),
      (ff,ffp,endow_comm),
      (tmmtax,tmmtaxp), (teetax,teetaxp),
      (smmtax,smmtaxp), (sddtax,sddtaxp), (sddtax,sddtaxp),
      (fftax,fftaxp),
      (otppmarg,otppmargp), (wtppmarg,wtppmargp), (atppmarg,atppmargp),
      (vsttmarg,vsttmargp),
      (ww,wwp), (kk,kkp,regp),
      (nonhh,nonhhp)
 ;

*#### PARAMETER DECLARATIONS

PARAMETERS
* GTAP Global SAM
 SAMG(ss,ssp,kk)        Social accounting matrices for regions k

* Factor based
 FacSubs(ff,aa,kk)      Factor-Based Subsidies by activity and region
 FacEmpTax(ff,aa,kk)    Factor Employment Tax Revenue

* Activity based
 OutSubs(dcc,kk)        Ordinary Output Subsidies

* Intermediate Input based
 IntInSubsM(mcc,aa,kk)  Imported intermediate input subsidies
 IntInSubsD(dcc,aa,kk)  Domestic intermediate input subsidies

* Export based
 MFASubs(dcc,ww,kk)     MFA Export Subsidy Equivalents
 OrdXSub(dcc,ww,kk)     Ordinary Export subsidies

* Import based
 OrdMDuty(ww,mcc,kk)    Ordinary Import duties

* GTAP Elasticities
 ESUBVA(aa)             CES between primary factors in production
 ESUBD(mcc)             Armington CES for domestic_imported allocation
 ESUBM(mcc)             Armington CES for regional allocation of imports

* GTAP Energy Volumes
 EVolF(en,aa,kk)        volume of input purchases by firms (Mtoe)
 EVolH(en,kk)           volume of purchases by households (Mtoe)
 EVolT(en,kk,kk)        volume of bilateral trade (Mtoe)

* GTAP Population data

 POPn(kk)               Population by region

* GTAP Time Series Trade data

 TSTRAD(dcc,kk,ww,tt)   Time series of trade flows between regions


 roundpar               Rounding parameter

* Parameters used to control model flow

 controls(cons,*)       initial values for controlling parameters

 DISP1              Control on DISPLAY Statements for read in SETS and DATA
 DISP2              Control on general DISPLAY Statements
 OUTGDXv1           Control on GDX Unload for SAMG v1
 OUTGDXv2           Control on GDX Unload for SAMG v2
 OUTGDXv3           Control on GDX Unload for SAMG v3
 OUTGDXv3g          Control on GDX Unload for SAMG v3g
 OUTREP             Control on Report outpurs

* Sales Tax rate parameters

 tsma(mcc,aa,kk)    Sales Taxes rates on imported commod by activities
 tsmh(mcc,*,kk)     Sales Taxes rates on imported commod by households
 tsmg(mcc,*,kk)     Sales Taxes rates on imported commod by government
 tsmk(mcc,*,kk)     Sales Taxes rates on imported commod by investment
 tsmnonh(mcc,kk)    Sales Taxes rates on imported commod by non hhold demand
 tvm(mcc,kk)        Implied VAT rates on imported commod by households

 tsda(dcc,aa,kk)    Sales Taxes rates on domestic commod by activities
 tsdh(dcc,*,kk)     Sales Taxes rates on domestic commod by households
 tsdg(dcc,*,kk)     Sales Taxes rates on domestic commod by government
 tsdk(dcc,*,kk)     Sales Taxes rates on domestic commod by investment
 tsdnonh(dcc,kk)    Sales Taxes rates on domestic commod by non hhold demand
 tvd(dcc,kk)        Implied VAT rates on domestic commod by households

* Sales Tax revenue parameters

 SMTAXA(mcc,aa,kk)  Sales Taxes revenues on imported commod by activities
 SMTAXH(mcc,*,kk)   Sales Taxes revenues on imported commod by households
 SMTAXG(mcc,*,kk)   Sales Taxes revenues on imported commod by government
 SMTAXK(mcc,*,kk)   Sales Taxes revenues on imported commod by investment

 SDTAXA(dcc,aa,kk)  Sales Taxes revenues on domestic commod by activities
 SDTAXH(dcc,*,kk)   Sales Taxes revenues on domestic commod by households
 SDTAXG(dcc,*,kk)   Sales Taxes revenues on domestic commod by government
 SDTAXK(dcc,*,kk)   Sales Taxes revenues on domestic commod by investment

* Sales Tax Report parameters

 tsmrates(kk,mcc,tsmset)  Summary info on sales taxes on imported commod
 tsdrates(kk,dcc,tsdset)  Summary info on sales taxes on domestic commod

* Value Added Tax Report parameters

 tvmrates(kk,mcc,tsmset)  Summary info on VAT taxes on imported commod
 tvdrates(kk,dcc,tsdset)  Summary info on VAT taxes on domestic commod

 tvmratesNEG(kk,mcc,tsmset)  Negative VAT taxes on imported commod
 tvdratesNEG(kk,dcc,tsdset)  Negative VAT taxes on domestic commod

* parameters for matrices of implied sales taxes and input subsidies

* Implied sales tax matrices

 SMTAXA2(mcc,aa,kk)    Implied Sales Taxes rev on imp commod by activities
 SMTAXH2(mcc,*,kk)     Implied Sales Taxes rev on imp commod by households
 SMTAXG2(mcc,*,kk)     Implied Sales Taxes rev on imp commod by government
 SMTAXK2(mcc,*,kk)     Implied Sales Taxes rev on imp commod by investment

 SDTAXA2(dcc,aa,kk)    Implied Sales Taxes rev on dom commod by activities
 SDTAXH2(dcc,*,kk)     Implied Sales Taxes rev on dom commod by households
 SDTAXG2(dcc,*,kk)     Implied Sales Taxes rev on dom commod by government
 SDTAXK2(dcc,*,kk)     Implied Sales Taxes rev on dom commod by investment

 tsmcom(mccts,kk)      Common sales tax rates for imp input subsidy commods
 tsdcom(dccts,kk)      Common sales tax rates for dom input subsidy commods

* input subsidy matrices

 INSUBMA(mcc,aa,kk)      Input subsidies for imp input subsidy commods
 INSUBMH(mcc,*,kk)       Input subsidies for imp input subsidy commods
 INSUBMG(mcc,*,kk)       Input subsidies for imp input subsidy commods
 INSUBMK(mcc,*,kk)       Input subsidies for imp input subsidy commods

 INSUBDA(dcc,aa,kk)      Input subsidies for dom input subsidy commods
 INSUBDH(dcc,*,kk)       Input subsidies for dom input subsidy commods
 INSUBDG(dcc,*,kk)       Input subsidies for dom input subsidy commods
 INSUBDK(dcc,*,kk)       Input subsidies for dom input subsidy commods

 INSUBMA2(smmtax,aa,kk)  Input subsidies for imp input subsidy commods
 INSUBMH2(smmtax,*,kk)   Input subsidies for imp input subsidy commods
 INSUBMG2(smmtax,*,kk)   Input subsidies for imp input subsidy commods
 INSUBMK2(smmtax,*,kk)   Input subsidies for imp input subsidy commods

 INSUBDA2(sddtax,aa,kk)  Input subsidies for dom input subsidy commods
 INSUBDH2(sddtax,*,kk)   Input subsidies for dom input subsidy commods
 INSUBDG2(sddtax,*,kk)   Input subsidies for dom input subsidy commods
 INSUBDK2(sddtax,*,kk)   Input subsidies for dom input subsidy commods

   ;

*############## 3. SET AND PARAMETER ASSIGNMENTS ##########################

* SETS are read in from an Excel

$CALL "GDXXRW i=data_glbsam_804_GLB2.xlsx o=data_in.gdx INDEX=LAYOUT!A4"

$GDXIN data_in.gdx

* SAMG Sets
$LOADdc ss
$LOADdc mcc mccts dcc dccts cc en
$LOADdc aa a2
$LOADdc ff
$LOADdc tmmtax teetax smmtax sddtax sstax fftax
$LOADdc otppmarg wtppmarg atppmarg vsttmarg
$LOADdc ww
$LOADdc ii
$LOADdc kk
$LOADdc tt
* Sets for reports on tax rates
$LOADdc tsmset tsdset
* Set for controlling parameters
$LOAD cons
* SEts for MAPS
$LOADdc mapsmtax mapinsubm mapstaxsm mapsdtax mapinsubd
$LOADdc mapstaxsd mapsimpcom mapsdomcom maptrad mapkk_ww
$LOAD mapcc_en

* Values for controlling parameters
$LOAD controls

$GDXIN

$GDXIN gtpdatav804.gdx

$LOAD SAMG   = SAMG

$LOAD FacSubs     = FacSubs
$LOAD FacEmpTax   = FacEmpTax
$LOAD OutSubs     = OutSubs
$LOAD IntInSubsM  = IntInSubsM
$LOAD IntInSubsD  = IntInSubsD
$LOAD MFASubs     = MFASubs
$LOAD OrdXSub     = OrdXSub
$LOAD OrdMDuty    = OrdMDuty

$LOAD ESUBVA = ESUBVA
$LOAD ESUBD  = ESUBD
$LOAD ESUBM  = ESUBM

*$LOAD EVolF  = EVolF
*$LOAD EVolH  = EVolH
*$LOAD EVolT  = EVolT

$LOAD POPn = POPn

$LOAD TSTRAD = TSTRAD

$GDXIN

* Assigning the rounding parameter

 roundpar      = 6 ;

* Assigning values to control parameters

 DISP1         = controls("conDISP1","base") ;
 DISP2         = controls("conDISP2","base") ;
 OUTGDXv1      = controls("conOUTGDXv1","base") ;
 OUTGDXv2      = controls("conOUTGDXv2","base") ;
 OUTGDXv3      = controls("conOUTGDXv3","base") ;
 OUTGDXv3g     = controls("conOUTGDXv3g","base") ;
 OUTREP        = controls("conOUTREP","base") ;

* Defining set members by reference to previously defined sets

 mcctsn(mcc)    = NOT mccts(mcc) ;
 dcctsn(dcc)    = NOT dccts(dcc) ;

* SAM Accounts excluding totals
 ssn(ss)        = YES ;
 ssn("TTOTAL")  = NO ;

* Other sets
 nonhh(aa)      = YES ;
 nonhh("ggovt") = YES ;
 nonhh("kkap")  = YES ;

IF(DISP1 = 1,

DISPLAY SAMG, controls ;

DISPLAY ss, ssn,
        mcc, mccts, mcctsn, dcc, dccts, dcctsn, cc, en, nonhh,
        aa, a2,
        ff,
        tmmtax, teetax, smmtax, sddtax, sstax, fftax,
        otppmarg, wtppmarg, atppmarg, vsttmarg,
        ww, ii, kk ;

DISPLAY tsmset, tsdset ;

DISPLAY mapsmtax, mapinsubm, mapstaxsm, mapsdtax, mapinsubd, mapstaxsd,
        mapsimpcom, mapsdomcom, maptrad, mapkk_ww, mapcc_en ;

   ) ;

*############## 4. LAW OF ONE PRICE ADJUSTMENTS ########################

*### Assigning Sales Tax revenue parameters

* Imports by Activities
 SMTAXA(mcc,aa,kk)      = SUM(smmtax
                          $MAPSMTAX(mcc,smmtax),
                          SAMG(smmtax,aa,kk)) ;

* Imports by Households
 SMTAXH(mcc,"HHOUS",kk) = SUM(smmtax
                          $MAPSMTAX(mcc,smmtax),
                          SAMG(smmtax,"HHOUS",kk)) ;

* Imports by Government
 SMTAXG(mcc,"GGOVT",kk) = SUM(smmtax
                          $MAPSMTAX(mcc,smmtax),
                          SAMG(smmtax,"GGOVT",kk)) ;

* Imports by Investment
 SMTAXK(mcc,"KKAP",kk)  = SUM(smmtax
                          $MAPSMTAX(mcc,smmtax),
                          SAMG(smmtax,"KKAP",kk)) ;

* Domestic by Activities
 SDTAXA(dcc,aa,kk)      = SUM(sddtax
                          $MAPSDTAX(dcc,sddtax),
                          SAMG(sddtax,aa,kk)) ;

* Domestic by Households
 SDTAXH(dcc,"HHOUS",kk) = SUM(sddtax
                          $MAPSDTAX(dcc,sddtax),
                          SAMG(sddtax,"HHOUS",kk)) ;

* Domestic by Government
 SDTAXG(dcc,"GGOVT",kk) = SUM(sddtax
                          $MAPSDTAX(dcc,sddtax),
                          SAMG(sddtax,"GGOVT",kk)) ;

* Domestic by Investment
 SDTAXK(dcc,"KKAP",kk) = SUM(sddtax
                          $MAPSDTAX(dcc,sddtax),
                          SAMG(sddtax,"KKAP",kk)) ;


*### ASSIGNING PARAMETERS

* Assigning Sales Tax rate parameters

 tsma(mcc,aa,kk)$SAMG(mcc,aa,kk)
                               = SMTAXA(mcc,aa,kk)/SAMG(mcc,aa,kk) ;

 tsmh(mcc,"HHOUS",kk)$SAMG(mcc,"HHOUS",kk)
                               = SMTAXH(mcc,"HHOUS",kk)/SAMG(mcc,"HHOUS",kk) ;

 tsmg(mcc,"GGOVT",kk)$SAMG(mcc,"GGOVT",kk)
                               = SMTAXG(mcc,"GGOVT",kk)/SAMG(mcc,"GGOVT",kk) ;

 tsmk(mcc,"KKAP",kk)$SAMG(mcc,"KKAP",kk)
                               = SMTAXK(mcc,"KKAP",kk)/SAMG(mcc,"KKAP",kk) ;

 tsmnonh(mcc,kk)$(SUM(aa,SAMG(mcc,aa,kk)) + SAMG(mcc,"KKAP",kk) + SAMG(mcc,"KKAP",kk))
                        = (SUM(aa,SMTAXA(mcc,aa,kk))
                           + SMTAXG(mcc,"GGOVT",kk) + SMTAXG(mcc,"KKAP",kk))
                            /(SUM(aa,SAMG(mcc,aa,kk))
                              + SAMG(mcc,"KKAP",kk) + SAMG(mcc,"KKAP",kk)) ;

 tvm(mcc,kk)                   = tsmh(mcc,"hhous",kk) - tsmnonh(mcc,kk) ;

 tsda(dcc,aa,kk)$SAMG(dcc,aa,kk)
                               = SDTAXA(dcc,aa,kk)/SAMG(dcc,aa,kk) ;

 tsdh(dcc,"HHOUS",kk)$SAMG(dcc,"HHOUS",kk)
                               = SDTAXH(dcc,"HHOUS",kk)/SAMG(dcc,"HHOUS",kk) ;

 tsdg(dcc,"GGOVT",kk)$SAMG(dcc,"GGOVT",kk)
                               = SDTAXG(dcc,"GGOVT",kk)/SAMG(dcc,"GGOVT",kk) ;

 tsdk(dcc,"KKAP",kk)$SAMG(dcc,"KKAP",kk)
                               = SDTAXK(dcc,"KKAP",kk)/SAMG(dcc,"KKAP",kk) ;

 tsdnonh(dcc,kk)$(SUM(aa,SAMG(dcc,aa,kk)) + SAMG(dcc,"KKAP",kk) + SAMG(dcc,"KKAP",kk))
                        = (SUM(aa,SDTAXA(dcc,aa,kk))
                           + SDTAXG(dcc,"GGOVT",kk) + SDTAXG(dcc,"KKAP",kk))
                            /(SUM(aa,SAMG(dcc,aa,kk))
                              + SAMG(dcc,"KKAP",kk) + SAMG(dcc,"KKAP",kk)) ;

 tvd(dcc,kk)                   = tsdh(dcc,"hhous",kk) - tsdnonh(dcc,kk) ;

*DISPLAY tsma ;

 tsmrates(kk,mcc,"mintsma")   = SMIN(aa$tsma(mcc,aa,kk),tsma(mcc,aa,kk)) ;
 tsmrates(kk,mcc,"avtsma")    = SUM(aa,tsma(mcc,aa,kk))/57 ;
 tsmrates(kk,mcc,"maxtsma")   = SMAX(aa,tsma(mcc,aa,kk)) ;
 tsmrates(kk,mcc,"tsmhous")   = tsmh(mcc,"HHOUS",kk) ;
 tsmrates(kk,mcc,"tsmgovt")   = tsmg(mcc,"GGOVT",kk) ;
 tsmrates(kk,mcc,"tsmkap")    = tsmk(mcc,"KKAP",kk) ;
 tsmrates(kk,mcc,"tsmnonhh")  = tsmnonh(mcc,kk) ;
 tsmrates(kk,mcc,"tvmhh")     = tvm(mcc,kk) ;

 tsdrates(kk,dcc,"mintsda")   = SMIN(aa$tsda(dcc,aa,kk),tsda(dcc,aa,kk)) ;
 tsdrates(kk,dcc,"avtsda")    = SUM(aa,tsda(dcc,aa,kk))/57 ;
 tsdrates(kk,dcc,"maxtsda")   = SMAX(aa,tsda(dcc,aa,kk)) ;
 tsdrates(kk,dcc,"tsdhous")   = tsdh(dcc,"HHOUS",kk) ;
 tsdrates(kk,dcc,"tsdgovt")   = tsdg(dcc,"GGOVT",kk) ;
 tsdrates(kk,dcc,"tsdkap")    = tsdk(dcc,"KKAP",kk) ;
 tsdrates(kk,dcc,"tsdnonhh")  = tsdnonh(dcc,kk) ;
 tsdrates(kk,dcc,"tvdhh")     = tvd(dcc,kk) ;

 tvmrates(kk,mcc,"tvmhh")     = tvm(mcc,kk) ;
 tvdrates(kk,dcc,"tvdhh")     = tvd(dcc,kk) ;

 tvmratesNEG(kk,mcc,"tvmhh")$(tvm(mcc,kk) LT 0.0)   = tvm(mcc,kk) ;
 tvdratesNEG(kk,dcc,"tvdhh")$(tvd(dcc,kk) LT 0.0)   = tvd(dcc,kk) ;

Parameter
 tvmratesNEGCNT  COUNT on negative VAT rates on Imports
 tvdratesNEGCNT  COUNT on negative VAT rates on Domestic ;

 tvmratesNEGCNT = SUM((kk,mcc)$tvmratesNEG(kk,mcc,"tvmhh"),1) ;
 tvdratesNEGCNT = SUM((kk,dcc)$tvdratesNEG(kk,dcc,"tvdhh"),1) ;

Display
  tvmratesNEGCNT, tvdratesNEGCNT
 ;

* Temporary FIX for value added rates

 tvmrates(kk,mcc,"tvmhh")     = tvm(mcc,kk) - tvmratesNEG(kk,mcc,"tvmhh") ;
 tvdrates(kk,dcc,"tvdhh")     = tvd(dcc,kk) - tvdratesNEG(kk,dcc,"tvdhh") ;

Parameter
 tvm2(mcc,kk)        Applied VAT rates on imported commod by households
 tvd2(dcc,kk)        Applied VAT rates on domestic commod by households
  ;

 tvm2(mcc,kk)       = tvmrates(kk,mcc,"tvmhh") ;
 tvd2(dcc,kk)       = tvdrates(kk,dcc,"tvdhh") ;

Parameter
 tvm2NEGCNT  COUNT on negative tvm2 VAT rates on Imports
 tvd2NEGCNT  COUNT on negative tvd2 VAT rates on Domestic ;

 tvm2NEGCNT = SUM((kk,mcc)$(tvm2(mcc,kk) LT 0.0),1) ;
 tvd2NEGCNT = SUM((kk,dcc)$(tvd2(dcc,kk) LT 0.0),1) ;

Display
  tvm2NEGCNT, tvd2NEGCNT
 ;

* tvmrates(kk,mcc,"tvmhh")$(tvm(mcc,kk) GE 0.0)     = tvm(mcc,kk) ;
* tvdrates(kk,dcc,"tvdhh")$(tvd(dcc,kk) GE 0.0)     = tvd(dcc,kk) ;

option tsmrates: 6:1:1 ;
option tsdrates: 6:1:1 ;

option tvmrates: 6:1:2 ;
option tvdrates: 6:1:2 ;

IF(DISP2 = 1,

DISPLAY tsmrates, tsdrates, tvmrates, tvdrates, tvmratesNEG, tvdratesNEG ;

  ) ;

* Defining common sales tax rates

 tsmcom(mccts,kk)    = tsmh(mccts,"HHOUS",kk) ;

 tsdcom(dccts,kk)    = tsdh(dccts,"HHOUS",kk) ;


 SMTAXA2(mccts,aa,kk)       = SAMG(mccts,aa,kk) * tsmcom(mccts,kk) ;
 SMTAXH2(mccts,"HHOUS",kk)  = SAMG(mccts,"HHOUS",kk) * tsmcom(mccts,kk) ;
 SMTAXG2(mccts,"GGOVT",kk)  = SAMG(mccts,"GGOVT",kk) * tsmcom(mccts,kk) ;
 SMTAXK2(mccts,"KKAP",kk)   = SAMG(mccts,"KKAP",kk) * tsmcom(mccts,kk) ;

 SDTAXA2(dccts,aa,kk)       = SAMG(dccts,aa,kk) * tsdcom(dccts,kk) ;
 SDTAXH2(dccts,"HHOUS",kk)  = SAMG(dccts,"HHOUS",kk) * tsdcom(dccts,kk) ;
 SDTAXG2(dccts,"GGOVT",kk)  = SAMG(dccts,"GGOVT",kk) * tsdcom(dccts,kk) ;
 SDTAXK2(dccts,"KKAP",kk)   = SAMG(dccts,"KKAP",kk) * tsdcom(dccts,kk) ;

 SMTAXA2(mcctsn,aa,kk)       = SMTAXA(mcctsn,aa,kk) ;
 SMTAXH2(mcctsn,"HHOUS",kk)  = SMTAXH(mcctsn,"HHOUS",kk) ;
 SMTAXG2(mcctsn,"GGOVT",kk)  = SMTAXG(mcctsn,"GGOVT",kk) ;
 SMTAXK2(mcctsn,"KKAP",kk)   = SMTAXK(mcctsn,"KKAP",kk) ;

 SDTAXA2(dcctsn,aa,kk)       = SDTAXA(dcctsn,aa,kk) ;
 SDTAXH2(dcctsn,"HHOUS",kk)  = SDTAXH(dcctsn,"HHOUS",kk) ;
 SDTAXG2(dcctsn,"GGOVT",kk)  = SDTAXG(dcctsn,"GGOVT",kk) ;
 SDTAXK2(dcctsn,"KKAP",kk)   = SDTAXK(dcctsn,"KKAP",kk) ;

*#### Rounding Sales Tax Adjustments to 6 Decimal Places
* The GTAP database only records data to 6 decimal places

 SMTAXA2(mcc,aa,kk)       = ROUND(SMTAXA2(mcc,aa,kk),roundpar) ;
 SMTAXH2(mcc,"HHOUS",kk)  = ROUND(SMTAXH2(mcc,"HHOUS",kk),roundpar) ;
 SMTAXG2(mcc,"GGOVT",kk)  = ROUND(SMTAXG2(mcc,"GGOVT",kk),roundpar) ;
 SMTAXK2(mcc,"KKAP",kk)   = ROUND(SMTAXK2(mcc,"KKAP",kk),roundpar) ;

 SDTAXA2(dcc,aa,kk)       = ROUND(SDTAXA2(dcc,aa,kk),roundpar) ;
 SDTAXH2(dcc,"HHOUS",kk)  = ROUND(SDTAXH2(dcc,"HHOUS",kk),roundpar) ;
 SDTAXG2(dcc,"GGOVT",kk)  = ROUND(SDTAXG2(dcc,"GGOVT",kk),roundpar) ;
 SDTAXK2(dcc,"KKAP",kk)   = ROUND(SDTAXK2(dcc,"KKAP",kk),roundpar) ;

* Calculating input subsidies
*$ontext
 INSUBMA(mccts,aa,kk)       = SMTAXA(mccts,aa,kk) - SMTAXA2(mccts,aa,kk) ;
 INSUBMH(mccts,"HHOUS",kk)  = SMTAXH(mccts,"HHOUS",kk)
                                - SMTAXH2(mccts,"HHOUS",kk) ;
 INSUBMG(mccts,"GGOVT",kk)  = SMTAXG(mccts,"GGOVT",kk)
                                - SMTAXG2(mccts,"GGOVT",kk) ;
 INSUBMK(mccts,"KKAP",kk)   = SMTAXK(mccts,"KKAP",kk)
                                - SMTAXK2(mccts,"KKAP",kk) ;

 INSUBDA(dccts,aa,kk)       = SDTAXA(dccts,aa,kk) - SDTAXA2(dccts,aa,kk) ;
 INSUBDH(dccts,"HHOUS",kk)  = SDTAXH(dccts,"HHOUS",kk)
                                - SDTAXH2(dccts,"HHOUS",kk) ;
 INSUBDG(dccts,"GGOVT",kk)  = SDTAXG(dccts,"GGOVT",kk)
                                - SDTAXG2(dccts,"GGOVT",kk) ;
 INSUBDK(dccts,"KKAP",kk)   = SDTAXK(dccts,"KKAP",kk)
                                - SDTAXK2(dccts,"KKAP",kk) ;

*#### Rounding Sales Tax Adjustments to 6 Decimal Places
* The GTAP database only records data to 6 decimal places

 INSUBMA(mcc,aa,kk)       = ROUND(INSUBMA(mcc,aa,kk),roundpar) ;
 INSUBMH(mcc,"HHOUS",kk)  = ROUND(INSUBMH(mcc,"HHOUS",kk),roundpar) ;
 INSUBMG(mcc,"GGOVT",kk)  = ROUND(INSUBMG(mcc,"GGOVT",kk),roundpar) ;
 INSUBMK(mcc,"KKAP",kk)   = ROUND(INSUBMK(mcc,"KKAP",kk),roundpar) ;

 INSUBDA(dcc,aa,kk)       = ROUND(INSUBDA(dcc,aa,kk),roundpar) ;
 INSUBDH(dcc,"HHOUS",kk)  = ROUND(INSUBDH(dcc,"HHOUS",kk),roundpar) ;
 INSUBDG(dcc,"GGOVT",kk)  = ROUND(INSUBDG(dcc,"GGOVT",kk),roundpar) ;
 INSUBDK(dcc,"KKAP",kk)   = ROUND(INSUBDK(dcc,"KKAP",kk),roundpar) ;

IF(DISP2 = 1,

DISPLAY tsmrates, tsdrates ;

DISPLAY tsmcom, tsdcom ;

DISPLAY INSUBMA, INSUBMH, INSUBMG, INSUBMK,
        INSUBDA, INSUBDH, INSUBDG, INSUBDK ;

   ) ;

*### Mappings for Input subsidy Accounts

 INSUBMA2(smmtax,aa,kk)      = SUM(mcc
                               $MAPINSUBM(smmtax,mcc),
                               INSUBMA(mcc,aa,kk)) ;

 INSUBMH2(smmtax,"HHOUS",kk) = SUM(mcc
                               $MAPINSUBM(smmtax,mcc),
                               INSUBMH(mcc,"HHOUS",kk)) ;

 INSUBMG2(smmtax,"GGOVT",kk) = SUM(mcc
                               $MAPINSUBM(smmtax,mcc),
                               INSUBMG(mcc,"GGOVT",kk)) ;

 INSUBMK2(smmtax,"KKAP",kk)  = SUM(mcc
                               $MAPINSUBM(smmtax,mcc),
                               INSUBMK(mcc,"KKAP",kk)) ;

 INSUBDA2(sddtax,aa,kk)      = SUM(dcc
                               $MAPINSUBD(sddtax,dcc),
                               INSUBDA(dcc,aa,kk)) ;

 INSUBDH2(sddtax,"HHOUS",kk) = SUM(dcc
                               $MAPINSUBD(sddtax,dcc),
                               INSUBDH(dcc,"HHOUS",kk)) ;

 INSUBDG2(sddtax,"GGOVT",kk) = SUM(dcc
                               $MAPINSUBD(sddtax,dcc),
                               INSUBDG(dcc,"GGOVT",kk)) ;

 INSUBDK2(sddtax,"KKAP",kk) = SUM(dcc
                              $MAPINSUBD(sddtax,dcc),
                              INSUBDK(dcc,"KKAP",kk)) ;

IF(DISP2 = 1,

DISPLAY INSUBMA2, INSUBMH2, INSUBMG2, INSUBMK2,
        INSUBDA2, INSUBDH2, INSUBDG2, INSUBDK2 ;

  ) ;
*$offtext

*## Writing out the Sales Tax Rates results to GDX

IF(OUTREP = 1,

Execute_Unload  'glbsam804_v2_SalTaxes.gdx',  tsmrates
                                           tsdrates
                                           tvmrates
                                           tvm2
                                           tvdrates
                                           tvd2
                                           tvmratesNEG
                                           tvdratesNEG
                                           tsmcom
                                           tsdcom
  ;

   )  ;

*############## 5. GLOBE SAM with SIMPLE SALES TAXES and VAT #############

*------- 5a. STAGE 1
$ontext

This stage creates a SAM under the implicit assumption that a law of
one price held in the base GTAP data. It is also assumed that the internal
balance for all regions was zero in the base period.

It retains the artifice of a Regional Household

$offtext

*#### Import commodity income components

* Revaluing imported commodities at purchaser prices

* Import Intermediate Use matrices (1:3)

 SAMG(mcc,aa,kk)           = SAMG(mcc,aa,kk) +  SMTAXA(mcc,aa,kk) ;

* Household import demand vectors (1:6)

 SAMG(mcc,"HHOUS",kk)      = SAMG(mcc,"HHOUS",kk) +  SMTAXH(mcc,"HHOUS",kk) ;

* Government import demand vectors (1:13)

 SAMG(mcc,"GGOVT",kk)      = SAMG(mcc,"GGOVT",kk) + SMTAXG(mcc,"GGOVT",kk) ;

* Investment import demand vectors (1:14)

 SAMG(mcc,"KKAP",kk)       = SAMG(mcc,"KKAP",kk) + SMTAXK(mcc,"KKAP",kk) ;

*#### Domestic commodity income components

* Revaluing domestic commodities at purchaser prices

* Domestic Intermediate Use matrices (2:3)

 SAMG(dcc,aa,kk)           =  SAMG(dcc,aa,kk) + SDTAXA(dcc,aa,kk) ;

* Household domestic demand vectors (2:6)

 SAMG(dcc,"HHOUS",kk)      =  SAMG(dcc,"HHOUS",kk) + SDTAXH(dcc,"HHOUS",kk) ;

* Government domestic demand vectors (2:13)

 SAMG(dcc,"GGOVT",kk)      = SAMG(dcc,"GGOVT",kk) + SDTAXG(dcc,"GGOVT",kk) ;

* Investment domestic demand vectors (2:14)

 SAMG(dcc,"KKAP",kk)       = SAMG(dcc,"KKAP",kk) + SDTAXK(dcc,"KKAP",kk) ;

*#### Indirect Tax Receipts for INDTAX(r) in GTAP model

* Deleting commodity specific sales taxes

* Intermediate Inputs (8:3)

 SAMG(smmtax,aa,kk)      = 0.0 ;

* Household Demand (9:6)

 SAMG(smmtax,"HHOUS",kk) = 0.0 ;

* Government Demand (9:13)

 SAMG(smmtax,"GGovt",kk) = 0.0 ;

* Investment Demand (9:14)

 SAMG(smmtax,"KKAP",kk)  = 0.0 ;

*# Domestic Sales Taxes

* Intermediate Inputs (8:3)

 SAMG(sddtax,aa,kk)      = 0.0 ;

* Household Demand (8:6)

 SAMG(sddtax,"HHOUS",kk) = 0.0 ;

* Government Demand (8:13)

 SAMG(sddtax,"GGovt",kk) = 0.0 ;

* Investment Demand (8:14)

 SAMG(sddtax,"KKAP",kk) = 0.0 ;

* Total Value Added Taxes Revenues on imports

 SAMG("vvattax",mcc,kk)  = (tvm2(mcc,kk) * SAMG(mcc,"HHOUS",kk)) ;

* Total Value Added Taxes Revenues on domestic commodities

 SAMG("vvattax",dcc,kk)  = (tvd2(dcc,kk) * SAMG(dcc,"HHOUS",kk)) ;

* Total Sales Taxes Revenues with common Sales Tax rates

 SAMG("SSALTAX",mcc,kk)  =  SUM(aa,SMTAXA(mcc,aa,kk))
                            + (SMTAXH(mcc,"HHOUS",kk)
                                 - (tvm2(mcc,kk) * SAMG(mcc,"HHOUS",kk)))
                            + SMTAXG(mcc,"GGOVT",kk)
                            + SMTAXK(mcc,"KKAP",kk) ;

* On domestic commodities

 SAMG("SSALTAX",dcc,kk)  =  SUM(aa,SDTAXA(dcc,aa,kk))
                            + (SDTAXH(dcc,"HHOUS",kk)
                                 - (tvd2(dcc,kk) * SAMG(dcc,"HHOUS",kk)))
                            + SDTAXG(dcc,"GGOVT",kk)
                            + SDTAXK(dcc,"KKAP",kk) ;

* Production taxes paid by activity

* Factor Use taxes paid by activities

 SAMG(fftax,aa,kk)  = SAMG(fftax,aa,kk) ;

* Indirect Production taxes to maintain activity account totals

 SAMG("pprodtax",aa,kk)  = SAMG("ttotal",aa,kk)
                           - (SUM(mcc,SAMG(mcc,aa,kk))
                                   + SUM(dcc,SAMG(dcc,aa,kk))
                           + SUM(ff,SAMG(ff,aa,kk))
                                   + SUM(fftax,SAMG(fftax,aa,kk))) ;

*#### Components of Regional Household Income

* Deleting commodity specific sales taxes

* Domestic Sales taxes (5:8)

 SAMG("rreghous",sddtax,kk)  = 0.0 ;

* Import Sales taxes (5:9)

 SAMG("rreghous",smmtax,kk)  = 0.0 ;

* Adding Value Added Taxes Revenues

 SAMG("rreghous","vvattax",kk)  = SUM(mcc,SAMG("vvattax",mcc,kk))
                                  + SUM(dcc,SAMG("vvattax",dcc,kk)) ;

* Adding Sales Taxes Revenues

 SAMG("rreghous","ssaltax",kk)  = SUM(mcc,SAMG("ssaltax",mcc,kk))
                                  + SUM(dcc,SAMG("ssaltax",dcc,kk)) ;

* Production Taxes (5:11)

* Updating Reg House income from production taxes

 SAMG("rreghous","pprodtax",kk)
                         = SUM(aa,SAMG("pprodtax",aa,kk)) ;

* Calculating Total Income of Regional Household

 SAMG("RREGHOUS","TTOTAL",kk)  = SUM(ff,SAMG("rreghous",ff,kk))
                                + SUM(tmmtax,SAMG("rreghous",tmmtax,kk))
                                + SUM(teetax,SAMG("rreghous",teetax,kk))
                                + SAMG("rreghous","ssaltax",kk)
                                + SAMG("rreghous","vvattax",kk)
                                + SUM(fftax,SAMG("rreghous",fftax,kk))
                                + SAMG("rreghous","pprodtax",kk)
                                + SAMG("rreghous","ddirtax",kk)  ;

*#### Components of Regional Household Expenditure

* Income of Private Households (6:5)

 SAMG("hhous","rreghous",kk)  = SUM(mcc,SAMG(mcc,"hhous",kk))
                                + SUM(dcc,SAMG(dcc,"hhous",kk)) ;

* Income of Government (13:5)

 SAMG("GGOVT","rreghous",kk) = SUM(mcc,SAMG(mcc,"ggovt",kk))
                               + SUM(dcc,SAMG(dcc,"ggovt",kk)) ;

* Domestic Savings (14:5)

 SAMG("KKAP","rreghous",kk)  = SAMG("rreghous","ttotal",kk)
                               - SAMG("hhous","rreghous",kk)
                               - SAMG("ggovt","rreghous",kk) ;

*#### Rounding the Global SAM to 6 Decimal Places
* The GTAP database only records data to 6 decimal places

 SAMG(ss,ssp,kk)      = ROUND(SAMG(ss,ssp,kk),roundpar) ;


*-------- 5b. STAGE 2
$ontext

This stage creates a SAM under the implicit assumption that a law of
one price held in the base GTAP data.

It is assumed that the internal balances for all regions were zero
in the base period.

$offtext

*#### Components of Regional Household Expenditure

* Income of Private Households (6:5)
* Moving factor incomes to HOUS from REG HOUSE

 SAMG("hhous",ff,kk)          = SAMG("rreghous",ff,kk) ;

 SAMG("RREGHOUS",ss,kk)   = 0.0 ;

 SAMG("rreghous",ff,kk)      = 0.0 ;

 SAMG("hhous","rreghous",kk)  = 0.0 ;

* Income of Government (13:5)
* Moving components of indirect taxes from REG HOUSE to GOVT

 SAMG("ggovt",tmmtax,kk)      = SUM(mcc, SAMG(tmmtax,mcc,kk)) ;

 SAMG("ggovt",teetax,kk)      = SUM(dcc,SAMG(teetax,dcc,kk)) ;

 SAMG("ggovt","vvattax",kk)   = SUM(mcc,SAMG("vvattax",mcc,kk))
                               + SUM(dcc,SAMG("vvattax",dcc,kk)) ;

 SAMG("ggovt","ssaltax",kk)   = SUM(mcc,SAMG("ssaltax",mcc,kk))
                               + SUM(dcc,SAMG("ssaltax",dcc,kk)) ;

 SAMG("ggovt",fftax,kk)       = SUM(aa,SAMG(fftax,aa,kk)) ;

 SAMG("ggovt","pprodtax",kk)  = SUM(aa,SAMG("pprodtax",aa,kk)) ;

* Domestic Savings (14:5)
* Defining Savings by HOUS as total investment expenditure LESS
* Depreciation, External balance on margins trade and commodity trade

 SAMG("KKAP","HHOUS",kk)     =  SAMG("ttotal","kkap",kk)
                               - SUM(ff,SAMG("kkap",ff,kk))
                               - SUM(vsttmarg,SAMG("kkap",vsttmarg,kk))
                               - SUM(ww,SAMG("kkap",ww,kk)) ;

* Deleting savings by REG HOUSE

 SAMG("kkap","rreghous",kk)  = 0.0 ;

* Income Tax paid by private household

* Defining HOUSE Income tax as HOUS Income less commodity expenditure and
* Savings by HOUSE

 SAMG("ddirtax","hhous",kk)  = SUM(ff,SAMG("hhous",ff,kk))
                              - SUM(mcc,SAMG(mcc,"hhous",kk))
                              - SUM(dcc,SAMG(dcc,"hhous",kk))
                              - SAMG("kkap","hhous",kk) ;


* Completing Govt Income by extending Direct Tax account

 SAMG("ggovt","ddirtax",kk)   = SUM(ff,SAMG("ddirtax",ff,kk))
                               + SAMG("ddirtax","hhous",kk) ;

 SAMG("ggovt","rreghous",kk)  = 0.0 ;

*#### Rounding the Global SAM to 6 Decimal Places
* The GTAP database only records data to 6 decimal places

 SAMG(ss,ssp,kk)      = ROUND(SAMG(ss,ssp,kk),roundpar) ;

*------- 5c. STAGE 3

$ontext

This stage creates a SAM under the implicit assumption that a law of
one price held in the base GTAP data.

The imported and domestic commodity accounts are aggregated to follow a
composite commodity type model - see McDonald & Thierfelder (2008)
for an example of this type of representation.

$offtext

* Commodity demand aggregation

 SAMG(cc,aa,kk)         = SUM(mcc$MAPSIMPCOM(cc,mcc),SAMG(mcc,aa,kk))
                          + SUM(dcc$MAPSDOMCOM(cc,dcc),SAMG(dcc,aa,kk)) ;

 SAMG(mcc,aa,kk)        = 0.0 ;
 SAMG(dcc,aa,kk)        = 0.0 ;

 SAMG(cc,"hhous",kk)    = SUM(mcc$MAPSIMPCOM(cc,mcc),SAMG(mcc,"hhous",kk))
                          + SUM(dcc$MAPSDOMCOM(cc,dcc),SAMG(dcc,"hhous",kk)) ;

 SAMG(mcc,"hhous",kk)   = 0.0 ;
 SAMG(dcc,"hhous",kk)   = 0.0 ;

 SAMG(cc,"ggovt",kk)    = SUM(mcc$MAPSIMPCOM(cc,mcc),SAMG(mcc,"ggovt",kk))
                          + SUM(dcc$MAPSDOMCOM(cc,dcc),SAMG(dcc,"ggovt",kk)) ;

 SAMG(mcc,"ggovt",kk)   = 0.0 ;
 SAMG(dcc,"ggovt",kk)   = 0.0 ;

 SAMG(cc,"kkap",kk)     = SUM(mcc$MAPSIMPCOM(cc,mcc),SAMG(mcc,"kkap",kk))
                          + SUM(dcc$MAPSDOMCOM(cc,dcc),SAMG(dcc,"kkap",kk)) ;

 SAMG(mcc,"kkap",kk)    = 0.0 ;
 SAMG(dcc,"kkap",kk)    = 0.0 ;

 SAMG(teetax,cc,kk)     = SUM(dcc$MAPSDOMCOM(cc,dcc),SAMG(teetax,dcc,kk)) ;

 SAMG(teetax,mcc,kk)    = 0.0 ;
 SAMG(teetax,dcc,kk)    = 0.0 ;

 SAMG(cc,vsttmarg,kk)   = SUM(dcc$MAPSDOMCOM(cc,dcc),SAMG(dcc,vsttmarg,kk)) ;

 SAMG(mcc,vsttmarg,kk)  = 0.0 ;
 SAMG(dcc,vsttmarg,kk)  = 0.0 ;

 SAMG(cc,ww,kk)         = SUM(dcc$MAPSDOMCOM(cc,dcc),SAMG(dcc,ww,kk)) ;

 SAMG(mcc,ww,kk)        = 0.0 ;
 SAMG(dcc,ww,kk)        = 0.0 ;

* Commodity Supply accounts

 SAMG(aa,cc,kk)         = SUM(dcc$MAPSDOMCOM(cc,dcc),SAMG(aa,dcc,kk)) ;

 SAMG(aa,dcc,kk)        = 0.0 ;

 SAMG(tmmtax,cc,kk)     = SUM(mcc$MAPSIMPCOM(cc,mcc),SAMG(tmmtax,mcc,kk)) ;

 SAMG(tmmtax,mcc,kk)    = 0.0 ;

 SAMG("vvattax",cc,kk)  = SUM(mcc$MAPSIMPCOM(cc,mcc),SAMG("vvattax",mcc,kk))
                          + SUM(dcc$MAPSDOMCOM(cc,dcc),SAMG("vvattax",dcc,kk)) ;

 SAMG("vvattax",mcc,kk) = 0.0 ;
 SAMG("vvattax",dcc,kk) = 0.0 ;

 SAMG("ssaltax",cc,kk)  = SUM(mcc$MAPSIMPCOM(cc,mcc),SAMG("ssaltax",mcc,kk))
                          + SUM(dcc$MAPSDOMCOM(cc,dcc),SAMG("ssaltax",dcc,kk)) ;

 SAMG("ssaltax",mcc,kk) = 0.0 ;
 SAMG("ssaltax",dcc,kk) = 0.0 ;

 SAMG(otppmarg,cc,kk)   = SUM(mcc$MAPSIMPCOM(cc,mcc),SAMG(otppmarg,mcc,kk)) ;

 SAMG(otppmarg,mcc,kk)  = 0.0 ;

 SAMG(wtppmarg,cc,kk)   = SUM(mcc$MAPSIMPCOM(cc,mcc),SAMG(wtppmarg,mcc,kk)) ;

 SAMG(wtppmarg,mcc,kk)  = 0.0 ;

 SAMG(atppmarg,cc,kk)   = SUM(mcc$MAPSIMPCOM(cc,mcc),SAMG(atppmarg,mcc,kk)) ;

 SAMG(atppmarg,mcc,kk)  = 0.0 ;

 SAMG(ww,cc,kk)         = SUM(mcc$MAPSIMPCOM(cc,mcc),SAMG(ww,mcc,kk)) ;

 SAMG(ww,mcc,kk)        = 0.0 ;

*#### Rounding the Global SAM to 6 Decimal Places
* The GTAP database only records data to 6 decimal places

 SAMG(ss,ssp,kk)      = ROUND(SAMG(ss,ssp,kk),roundpar) ;

*--------- 5d. STAGE 4

$ontext

This stage allocates expenditures and incomes to the GLOBE region.

$offtext

* Making sure there are no entries in GLOBE's SAM

 SAMG(ss,ssp,"glo")  = 0.0 ;

*### Imports of Margins by GLOBE

* Setting margin exports to GLOBE

 SAMG(cc,"wwglo",kk)    = SUM(vsttmarg,SAMG(cc,vsttmarg,kk)) ;

 SAMG(cc,vsttmarg,kk)   = 0.0 ;

* Imports of Margins by GLOBE

 SAMG(ww,cc,"glo")      =SUM(kk$MAPTRAD(ww,kk),SAMG(cc,"wwglo",kk)) ;

Parameter

 margchk1(cc)      Margins check for margin imports by GLOBE

 ;

 margchk1(cc)   = SUM(kk,SAMG(cc,"wwglo",kk)) - SUM(ww,SAMG(ww,cc,"glo")) ;

DISPLAY  margchk1 ;

*### Exports of Margins by GLOBE

* Margin imports by Region

Parameter

 margimps(cc,kk)    Margin imports of type cc by region kk

  ;

 margimps("ccotp",kk)  = SUM((otppmarg,cc),SAMG(otppmarg,cc,kk)) ;
 margimps("ccwtp",kk)  = SUM((wtppmarg,cc),SAMG(wtppmarg,cc,kk)) ;
 margimps("ccatp",kk)  = SUM((atppmarg,cc),SAMG(atppmarg,cc,kk)) ;

DISPLAY margimps ;

* Margin Exports by GLOBE

 SAMG(cc,ww,"glo")    = SUM(kk$MAPTRAD(ww,kk),margimps(cc,kk)) ;

Parameter

 margchk2(cc)      Margins check for margin exports by GLOBE

 ;

 margchk2(cc)   = SUM((otppmarg,kk),SAMG(otppmarg,cc,kk))
                    + SUM((wtppmarg,kk),SAMG(wtppmarg,cc,kk))
                    + SUM((atppmarg,kk),SAMG(atppmarg,cc,kk))
                    - SUM(ww,SAMG(cc,ww,"glo")) ;

DISPLAY  margchk2 ;

*### Calculating trade balances with GLOBE

* Clearing out trade balances wrt VSTTMARG

 SAMG(ss,VSTTMARG,kk)   = 0.0 ;
 SAMG(VSTTMARG,ss,kk)   = 0.0 ;

* Calculating the import demand for each margin import

 SAMG("wwglo",otppmarg,kk)  = SUM(cc,SAMG(otppmarg,cc,kk)) ;
 SAMG("wwglo",wtppmarg,kk)  = SUM(cc,SAMG(wtppmarg,cc,kk)) ;
 SAMG("wwglo",atppmarg,kk)  = SUM(cc,SAMG(atppmarg,cc,kk)) ;

* Calculating trade balance for each region with the GLOBE

 SAMG("kkap","wwglo",kk)   =  SUM(otppmarg,SAMG("wwglo",otppmarg,kk))
                              + SUM(wtppmarg,SAMG("wwglo",wtppmarg,kk))
                              + SUM(atppmarg,SAMG("wwglo",atppmarg,kk))
                                 - SUM(cc,SAMG(cc,"wwglo",kk)) ;

* Calculating GLOBE's trade balance with each region

 SAMG("kkap",ww,"glo")     = SUM(cc,SAMG(ww,cc,"glo"))
                             - SUM(ccp,SAMG(ccp,ww,"glo")) ;

*############## 7. CHECKING THE NEW GLOBAL SAMGg ########################

* This checking of the Global SAM is important.

*#### Computing Account totals for Global SAM by Region

 SAMG("TTOTAL",ssnp,kk)        = SUM(ssn,SAMG(ssn,ssnp,kk)) ;

 SAMG(ssn,"TTOTAL",kk)         = SUM(ssnp,SAMG(ssn,ssnp,kk)) ;

Parameter
 COLTOT3(*,kk)       Check on region column totals
 ROWTOT3(kk,*)       Check on region row totals
 DIFFTOT3(*,kk)      Check on difference in region column and row totals
 SUMDIFFTOT3(kk)     Sum of differences in region row and column totals
 DIFFPER3(*,kk)      Percent differences in region column and row totals
 ;

 COLTOT3(ssnp,kk)    = SUM(ssn,SAMG(ssn,ssnp,kk)) ;
 ROWTOT3(kk,ssn)     = SUM(ssnp,SAMG(ssn,ssnp,kk)) ;

 DIFFTOT3(ssnp,kk)   = COLTOT3(ssnp,kk) - ROWTOT3(kk,ssnp) ;

 DIFFTOT3(ssnp,kk)   = ROUND(DIFFTOT3(ssnp,kk),roundpar ) ;

 SUMDIFFTOT3(kk)     = SUM(ssnp,DIFFTOT3(ssnp,kk)) ;

 DIFFPER3(ssnp,kk)$COLTOT3(ssnp,kk)
      = (DIFFTOT3(ssnp,kk)/(0.5 * (COLTOT3(ssnp,kk)
                                    + ROWTOT3(kk,ssnp)))) * 100 ;

 DIFFPER3(ssnp,kk)   = ROUND(DIFFPER3(ssnp,kk),roundpar ) ;

option decimals = 8 ;

DISPLAY COLTOT3, ROWTOT3, DIFFTOT3, DIFFPER3, SUMDIFFTOT3 ;

*## Writing out the CHECK results to GDX

IF(OUTGDXv3g = 1,

Execute_Unload  'glbsam804_GLBv2_chk.gdx', COLTOT3
                                         ROWTOT3
                                         DIFFTOT3
                                         DIFFPER3
                                         SUMDIFFTOT3
  ;

  ) ;

*###### Creating a version of the GTAP SAM with margin exports to GLOBE
 PARAMETERS

 SAMGg(SS,SSP,KK)    Social accounting matrices for regions k using GLOBE

;

 SAMGg(ss,ssp,kk)   = SAMG(ss,ssp,kk) ;


*############## 8. ORGANISING ADDITIONAL GTAP DATA #######################
* ### Relabelling additional data parameters where necessary

Parameter
* GTAP Elasticities
 ESUBD2(cc)          Armington CES for domestic_imported allocation
 ESUBM2(cc)          Armington CES for regional allocation of imports

* GTAP Energy Volumes
 EVolF2(cc,aa,kk)    volume of input purchases by firms (Mtoe)
 EVolH2(cc,kk)       volume of purchases by households (Mtoe)
 EVolT2(cc,kk,ww)    volume of bilateral trade (Mtoe)

* Activity based
 OutSubs2(cc,kk)         Ordinary Output Subsidies

* Intermediate Input based
 IntInSubsM2(cc,aa,kk)  Imported intermediate input subsidies
 IntInSubsD2(cc,aa,kk)  Domestic intermediate input subsidies

* Export based
 MFASubs2(cc,ww,kk)     MFA Export Subsidy Equivalents
 OrdXSub2(cc,ww,kk)     Ordinary Export subsidies

* Import based
 OrdMDuty2(ww,cc,kk)    Ordinary Import duties

  ;

* GTAP Elasticities
 ESUBD2(cc)        = SUM(mcc$MAPSIMPCOM(cc,mcc),ESUBD(mcc)) ;

 ESUBM2(cc)        = SUM(mcc$MAPSIMPCOM(cc,mcc),ESUBM(mcc)) ;

* GTAP Energy Volumes
$ontext
 EVolF2(cc,aa,kk)  = SUM(en$mapcc_en(cc,en),EVolF(en,aa,kk)) ;

 EVolH2(cc,kk)     = SUM(en$mapcc_en(cc,en),EVolH(en,kk)) ;

 EVolT2(cc,kk,ww)  = SUM((en,kkp)$(mapcc_en(cc,en)$maptrad(ww,kkp)),
                           EVolT(en,kk,kkp)) ;
$offtext

* ### Relabelling times series trade data

Parameter
* GTAP Time Series Trade data

 TSTRAD2(cc,kk,ww,tt) Time series of trade flows between regions

  ;

 TSTRAD2(cc,kk,ww,tt)  = SUM(dcc$MAPSDOMCOM(cc,dcc),TSTRAD(dcc,kk,ww,tt)) ;

* Activity based
 OutSubs2(cc,kk)        = SUM(dcc
                          $MAPSDOMCOM(cc,dcc),OutSubs(dcc,kk)) ;

* Intermediate Input based
 IntInSubsM2(cc,aa,kk)  =  SUM(mcc
                         $MAPSIMPCOM(cc,mcc),IntInSubsM(mcc,aa,kk)) ;

 IntInSubsD2(cc,aa,kk)  = SUM(dcc
                          $MAPSDOMCOM(cc,dcc),IntInSubsD(dcc,aa,kk)) ;

* Export based
 MFASubs2(cc,ww,kk)     = SUM(dcc
                          $MAPSDOMCOM(cc,dcc),MFASubs(dcc,ww,kk)) ;

 OrdXSub2(cc,ww,kk)     = SUM(dcc
                          $MAPSDOMCOM(cc,dcc),OrdXSub(dcc,ww,kk)) ;

* Import based
 OrdMDuty2(ww,cc,kk)    = SUM(mcc
                           $MAPSIMPCOM(cc,mcc),OrdMDuty(ww,mcc,kk)) ;

*############## 9. CHECKING THE NEW GLOBAL SAMGg #########################

* This checking of the Global SAM is important.

*#### Computing Account totals for Global SAM by Region

 SAMG("TTOTAL",ssnp,kk)        = SUM(ssn,SAMG(ssn,ssnp,kk)) ;

 SAMG(ssn,"TTOTAL",kk)         = SUM(ssnp,SAMG(ssn,ssnp,kk)) ;

Parameter
 COLTOT4(*,kk)       Check on region column totals
 COLTOT4CHK(*,kk)    Check on Check on region column totals
 ROWTOT4(kk,*)       Check on region row totals
 ROWTOT4CHK(kk,*)    Check on Check on region row totals
 DIFFTOT4(*,kk)      Check on difference in region column and row totals
 SUMDIFFTOT4(kk)     Sum of differences in region row and column totals
 DIFFPER4(*,kk)      Percent differences in region column and row totals
 ;

 COLTOT4(ssnp,kk)    = SUM(ssn,SAMG(ssn,ssnp,kk)) ;
 ROWTOT4(kk,ssn)     = SUM(ssnp,SAMG(ssn,ssnp,kk)) ;

 COLTOT4CHK(ssnp,kk)$(COLTOT4(ssnp,kk) = 0.0) = 1.0 ;
 ROWTOT4CHK(kk,ssn)$(ROWTOT4(kk,ssn) = 0.0)   = 1.0 ;

Display COLTOT4CHK, ROWTOT4CHK ;

 DIFFTOT4(ssnp,kk)   = COLTOT4(ssnp,kk) - ROWTOT4(kk,ssnp) ;

 DIFFTOT4(ssnp,kk)   = ROUND(DIFFTOT4(ssnp,kk),roundpar ) ;

 SUMDIFFTOT4(kk)     = SUM(ssnp,DIFFTOT4(ssnp,kk)) ;

 DIFFPER4(ssnp,kk)$COLTOT4(ssnp,kk)
      = (DIFFTOT4(ssnp,kk)/(0.5 * (COLTOT4(ssnp,kk)
                                    + ROWTOT4(kk,ssnp)))) * 100 ;

 DIFFPER4(ssnp,kk)   = ROUND(DIFFPER4(ssnp,kk),roundpar ) ;

option decimals = 8 ;

DISPLAY COLTOT4, ROWTOT4, DIFFTOT4, DIFFPER4, SUMDIFFTOT4 ;

*############## 10. REMOVING SMALL ENTRIES ################################

Parameter

 SAMG_sm(ss,ssp,kk)     SAMG of Small Entries
 ADJUST(ss,kk)          Adjusts to balance SAMG after removing small entries
  ;

 SAMG_sm(ss,ssp,kk)$(ABS(SAMG(ss,ssp,kk)) LT 0.001) = SAMG(ss,ssp,kk) ;

*Display SAMG_sm ;

 SAMG(ss,ssp,kk)   = SAMG(ss,ssp,kk)- SAMG_sm(ss,ssp,kk) ;

*#### Computing Revised Account totals for Global SAM by Region

 SAMG("TTOTAL",ssnp,kk)        = SUM(ssn,SAMG(ssn,ssnp,kk)) ;

 SAMG(ssn,"TTOTAL",kk)         = SUM(ssnp,SAMG(ssn,ssnp,kk)) ;

* ## Differences in account totals

 COLTOT4(ssnp,kk)    = SUM(ssn,SAMG(ssn,ssnp,kk)) ;
 ROWTOT4(kk,ssn)     = SUM(ssnp,SAMG(ssn,ssnp,kk)) ;

 ADJUST(ssn,kk)      = ROWTOT4(kk,ssn) - COLTOT4(ssn,kk) ;

option decimals = 8 ;

DISPLAY  SAMG_sm, ADJUST ;


* #### Mechanical Rebalancing of SAMG

 SAMG("ssaltax",cc,kk) = SAMG("ssaltax",cc,kk) + ADJUST(cc,kk) ;

 SAMG("pprodtax",aa,kk) = SAMG("pprodtax",aa,kk) + ADJUST(aa,kk) ;

 SAMG("ggovt",tmmtax,kk) = SUM(cc,SAMG(tmmtax,cc,kk)) ;

 SAMG("ggovt",teetax,kk) = SUM(cc,SAMG(teetax,cc,kk)) ;

 SAMG("ggovt",fftax,kk) = SUM(aa,SAMG(fftax,aa,kk)) ;

* Calculating Household incomes from factors

 SAMG("hhous",ff,kk)    = SUM(aa,SAMG(ff,aa,kk))
                           - SAMG("ddirtax",ff,kk) - SAMG("kkap",ff,kk) ;

* Calculating the import demand for each margin import

 SAMG("wwglo",otppmarg,kk)  = SUM(cc,SAMG(otppmarg,cc,kk)) ;
 SAMG("wwglo",wtppmarg,kk)  = SUM(cc,SAMG(wtppmarg,cc,kk)) ;
 SAMG("wwglo",atppmarg,kk)  = SUM(cc,SAMG(atppmarg,cc,kk)) ;

* Calculating trade balance for each region with other regions

 SAMG("kkap",ww,kk)    = SUM(cc,SAMG(ww,cc,kk)) - SUM(ccp,SAMG(ccp,ww,kk)) ;

* Calculating trade balance for each region with the GLOBE

 SAMG("kkap","wwglo",kk)   =  SUM(otppmarg,SAMG("wwglo",otppmarg,kk))
                              + SUM(wtppmarg,SAMG("wwglo",wtppmarg,kk))
                              + SUM(atppmarg,SAMG("wwglo",atppmarg,kk))
                                 - SUM(cc,SAMG(cc,"wwglo",kk)) ;

* Calculating GLOBE's trade balance with each region

 SAMG("kkap",ww,"glo")     = SUM(cc,SAMG(ww,cc,"glo"))
                             - SUM(ccp,SAMG(ccp,ww,"glo")) ;

* Calculating Government tax revenues

 SAMG("ggovt","ssaltax",kk) = SUM(cc,SAMG("ssaltax",cc,kk)) ;

 SAMG("ggovt","vvattax",kk) = SUM(cc,SAMG("vvattax",cc,kk)) ;

 SAMG("ggovt","pprodtax",kk) = SUM(aa,SAMG("pprodtax",aa,kk)) ;

 SAMG("ggovt","ddirtax",kk) = SUM(ff,SAMG("ddirtax",ff,kk))
                               + SAMG("ddirtax","hhous",kk) ;

* Calculating Institutional Savings

 SAMG("kkap","hhous",kk)    = SUM(ff,SAMG("hhous",ff,kk))
                               - SUM(cc,SAMG(cc,"hhous",kk))
                               - SAMG("ddirtax","hhous",kk) ;

 SAMG("kkap","ggovt",kk)    = SUM(tmmtax,SAMG("ggovt",tmmtax,kk))
                               + SUM(teetax,SAMG("ggovt",teetax,kk))
                               + SUM(fftax,SAMG("ggovt",fftax,kk))
                               + SAMG("ggovt","ssaltax",kk)
                               + SAMG("ggovt","vvattax",kk)
                               + SAMG("ggovt","pprodtax",kk)
                               + SAMG("ggovt","ddirtax",kk)
                               - SUM(cc,SAMG(cc,"ggovt",kk)) ;

*############## 11. RE CHECKING THE NEW GLOBAL SAMGg #####################

* This checking of the Global SAM is important.

*#### Computing Account totals for Global SAM by Region

 SAMG("TTOTAL",ssnp,kk)        = SUM(ssn,SAMG(ssn,ssnp,kk)) ;

 SAMG(ssn,"TTOTAL",kk)         = SUM(ssnp,SAMG(ssn,ssnp,kk)) ;

Parameter
 COLTOT5(*,kk)       Check on region column totals
 COLTOT5CHK(*,kk)    Check on Check on region column totals
 ROWTOT5(kk,*)       Check on region row totals
 ROWTOT5CHK(kk,*)    Check on Check on region row totals
 DIFFTOT5(*,kk)      Check on difference in region column and row totals
 SUMDIFFTOT5(kk)     Sum of differences in region row and column totals
 DIFFPER5(*,kk)      Percent differences in region column and row totals
 ;

 COLTOT5(ssnp,kk)    = SUM(ssn,SAMG(ssn,ssnp,kk)) ;
 ROWTOT5(kk,ssn)     = SUM(ssnp,SAMG(ssn,ssnp,kk)) ;

 COLTOT5CHK(ssnp,kk)$(COLTOT5(ssnp,kk) = 0.0) = 1.0 ;
 ROWTOT5CHK(kk,ssn)$(ROWTOT5(kk,ssn) = 0.0)   = 1.0 ;

Display COLTOT5CHK, ROWTOT5CHK ;

 DIFFTOT5(ssnp,kk)   = COLTOT5(ssnp,kk) - ROWTOT5(kk,ssnp) ;

 DIFFTOT5(ssnp,kk)   = ROUND(DIFFTOT5(ssnp,kk),roundpar ) ;

 SUMDIFFTOT5(kk)     = SUM(ssnp,DIFFTOT5(ssnp,kk)) ;

 DIFFPER5(ssnp,kk)$COLTOT5(ssnp,kk)
      = (DIFFTOT5(ssnp,kk)/(0.5 * (COLTOT5(ssnp,kk)
                                    + ROWTOT5(kk,ssnp)))) * 100 ;

 DIFFPER5(ssnp,kk)   = ROUND(DIFFPER5(ssnp,kk),roundpar ) ;

option decimals = 8 ;

DISPLAY COLTOT5, ROWTOT5, DIFFTOT5, DIFFPER5, SUMDIFFTOT5 ;

*############## 12. WRITING THE NEW GLOBAL SAM TO GDX ####################

*## Writing out the GTAP NEW SAM to GDX

IF(OUTGDXv3g = 1,

* This writes all the SAM data to GDX
Execute_Unload  'glbsam804_GLBv2.gdx', SAMGg
* GTAP Elasticity Values
                                   ESUBVA,
                                   ESUBD2,
                                   ESUBM2,

* GTAP Energy Volumes
*                                   EVolF2,
*                                   EVolH2,
*                                   EVolT2,
* Factor based
                                   FacSubs,
                                   FacEmpTax,
* Activity based
                                   OutSubs2,
* Intermediate Input based
                                   IntInSubsM2,
                                   IntInSubsD2,
* Export based
                                   MFASubs2,
                                   OrdXSub2,
* Import based
                                   OrdMDuty2,
* GTAP population data
                                   Popn,
* GTAP Time series trade data
                                   TSTRAD2

  ;

   )  ;


*############## 13. COMPUTING TAX RATES ###################################

* #### Computed tax rates for checking impact of changes on tax rates

Parameter
 te0(cc,ww,kk)      Export tax rates on exports of comm'y c to region w
 tm0(ww,cc,kk)      Tariff rates on comm'y imported from region w
 ts0(cc,kk)         Base sales tax rate
 tv0(cc,kk)         Base Value added tax rates
 tx0(aa,kk)         Base indirect tax rate on activity a
 tyf0(ff,kk)        Factor income tax rate
 tyh0(*,kk)         Direct tax rate on household h
 tf0(ff,aa,kk)      Factor use tax rate
 ;

 ts0(cc,kk)$(SUM(aa,SAMG(cc,aa,kk)) + SAMG(cc,"HHOUS",kk) + SAMG(cc,"GGOVT",kk)
                              + SAMG(cc,"KKAP",kk) - SAMG("SSALTAX",cc,kk)
                                        - SAMG("VVATTAX",cc,kk))
                 = SAMG("SSALTAX",cc,kk)/(SUM(aa,SAMG(cc,aa,kk))
                                       + SAMG(cc,"HHOUS",kk)
                                       + SAMG(cc,"GGOVT",kk)
                                       + SAMG(cc,"KKAP",kk)
                                       - SAMG("SSALTAX",cc,kk)
                                       - SAMG("VVATTAX",cc,kk) ) ;

 tv0(cc,kk)$(SAMG(cc,"HHOUS",kk) - SAMG("VVATTAX",cc,kk))
             = SAMG("VVATTAX",cc,kk)/
                (SAMG(cc,"HHOUS",kk) - SAMG("VVATTAX",cc,kk));

 tx0(aa,kk)$SAMG("TTOTAL",aa,kk)
             = SAMG("PPRODTAX",aa,kk)/SAMG("TTOTAL",aa,kk) ;

 tyf0(ff,kk)$(SAMG("TTOTAL",ff,kk) - SAMG("KKAP",ff,kk))
             = SAMG("DDIRTAX",ff,kk)/(SAMG("TTOTAL",ff,kk) - SAMG("KKAP",ff,kk)) ;

 tyh0("HHOUS",kk)$SAMG("TTOTAL","HHOUS",kk)
             = SAMG("DDIRTAX","HHOUS",kk)/SAMG("TTOTAL","HHOUS",kk) ;

Display ts0, tv0, tx0, tyh0, tyf0 ;

Parameter

 tv0_perc(cc,kk)     Percentage rates for VAT
 tv0_big(cc,kk)      Big percentage rates for VAT
 tv0_smal(cc,kk)     Small percentage rates for VAT

 tyh0_perc(*,kk)     Percentage rates for household income taxes
 tyh0_big(*,kk)      Big percentage rates for household income taxes

 tyf0_perc(ff,kk)    Percentage rates for factor income taxes
 tyf0_big(ff,kk)     Big percentage rates for factor income taxes

  ;

 tv0_perc(cc,kk)   = tv0(cc,kk) *100 ;

 tv0_big(cc,kk)$(ABS(tv0_perc(cc,kk) GT 25)) = tv0_perc(cc,kk) ;

 tv0_smal(cc,kk)$(ABS(tv0_perc(cc,kk) LT 1)) = tv0_perc(cc,kk) ;

 tyh0_perc("HHOUS",kk)   = tyh0("HHOUS",kk) *100 ;

 tyh0_big("HHOUS",kk)$(ABS(tyh0_perc("HHOUS",kk) GT 25)) = tyh0_perc("HHOUS",kk) ;

 tyf0_perc(ff,kk)    =  tyf0(ff,kk) * 100 ;

 tyf0_big(ff,kk)$(ABS(tyf0_perc(ff,kk) GT 10))  = tyf0_perc(ff,kk) ;

Option Decimals = 3 ;

Display tv0_perc, tv0_big, tv0_smal, tyh0_perc, tyh0_big, tyf0_perc, tyf0_big ;

Execute_Unload  'glb804_v2_tax_rate.gdx', tv0_perc
                                         tv0_big
                                         tv0_smal
                                         tyh0_perc
                                         tyh0_big
                                         tyf0_perc
                                         tyf0_big
  ;

*########################### THE END #####################################
